@@ -6,7 +6,7 @@ class CloudResourceManagerFacade(GCPBaseFacade):
     def __init__(self):
         super(CloudResourceManagerFacade, self).__init__('cloudresourcemanager', 'v1')
 
-    async def get_bindings(self, project_id: str):
+    async def get_member_bindings(self, project_id: str):
         try:
             cloudresourcemanager_client = self._get_client()
             response = await run_concurrently(
