@@ -5,6 +5,7 @@ from ScoutSuite.providers.utils import run_concurrently
 
 
 class StackdriverLoggingFacade:
+
     async def get_sinks(self, project_id: str):
         try:
             client = stackdriverlogging.Client(project=project_id)
@@ -12,3 +13,11 @@ class StackdriverLoggingFacade:
         except Exception as e:
             print_exception('Failed to retrieve sinks: {}'.format(e))
             return []
+
+    async def get_metrics(self, project_id: str):
+        try:
+            client = stackdriverlogging.Client(project=project_id)
+            return await run_concurrently(lambda: [metric for metric in client.list_metrics()])
+        except Exception as e:
+            print_exception('Failed to retrieve metrics: {}'.format(e))
+            return []
