@@ -19,10 +19,10 @@ class Keys(Resources):
         key_dict = {}
 
         key_dict['id'] = raw_key['name'].split('/')[-1]
-        key_dict['state'] = raw_key['primary']['state']
-        key_dict['creation_datetime'] = raw_key['primary']['createTime']
-        key_dict['protection_level'] = raw_key['primary']['protectionLevel']
-        key_dict['algorithm'] = raw_key['primary']['algorithm']
+        key_dict['state'] = raw_key.get('primary', {}).get('state', None)
+        key_dict['creation_datetime'] = raw_key.get('primary', {}).get('createTime', None)
+        key_dict['protection_level'] = raw_key.get('primary', {}).get('protectionLevel', None)
+        key_dict['algorithm'] = raw_key.get('primary', {}).get('algorithm', None)
         key_dict['next_rotation_datetime'] = raw_key.get('nextRotationTime', None)
         key_dict['purpose'] = raw_key['purpose']
         key_dict['rotation_period'] = raw_key.get('rotationPeriod', None)
